###############
Windows classes
###############

.. automodule:: pymeasure.display.windows.managed_image_window
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.windows.managed_window
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.windows.plotter_window
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.windows.managed_dock_window
    :members:
    :show-inheritance: